@@ -173,6 +173,7 @@ class AutoTraderBot():
         # Assign strategy to local attributes
         self.strategy           = my_strat
         self.data               = data
+        self.MTF_data           = MTF_data
         self.quote_data         = quote_data
         self.latest_orders      = []
         
@@ -183,7 +184,7 @@ class AutoTraderBot():
             self.strategy._tick_data = True
         
         if int(self.verbosity) > 0:
-                print("\nAutoTraderBot assigned to analyse {}".format(instrument),
+                print("\nAutoTraderBot assigned to trade {}".format(instrument),
                       "on {} timeframe using {}.".format(self.strategy_params['granularity'],
                                                          strategy_config['NAME']))
     
@@ -259,7 +260,6 @@ class AutoTraderBot():
         interval    = self.strategy_params['granularity']
         period      = self.strategy_params['period']
         price_data_path = os.path.join(self.home_dir, 'price_data')
-        # TODO - assign price_data_path attribute 
         
         if self.backtest_mode is True:
             ' ~~~~~~~~~~~~~~~~~~~ Running in backtest mode ~~~~~~~~~~~~~~~~~~ '
@@ -274,9 +274,11 @@ class AutoTraderBot():
                 custom_data_filepath    = os.path.join(price_data_path, custom_data_file) if not self.abs_data_filepath else custom_data_file
                 if int(self.verbosity) > 1:
                     print("Using data file specified ({}).".format(custom_data_file))
-                data            = pd.read_csv(custom_data_filepath, 
-                                              index_col = 0)
+                data = pd.read_csv(custom_data_filepath, index_col = 0)
                 data.index = pd.to_datetime(data.index, utc=True)
+                
+                # Adjust for start and end dates
+                data = self._check_data_period(data, from_date, to_date)
                 quote_data = data
                 
                 MTF_data = None
@@ -296,6 +298,9 @@ class AutoTraderBot():
                     data = pd.read_csv(custom_data_filepath, index_col = 0)
                     data.index = pd.to_datetime(data.index, utc=True)
                     
+                    # Adjust for start and end dates
+                    data = self._check_data_period(data, from_date, to_date)
+                    
                     if granularity == MTF_granularities[0]:
                         quote_data = data
                     
@@ -574,6 +579,14 @@ class AutoTraderBot():
             
             return data, None, MTF_data
 
+    def _check_data_period(self, data, from_date, to_date):
+        ''' 
+        Checks and returns the dataset matching the backtest start and 
+        end dates (as close as possible).
+        '''
+        
+        return data[(data.index >= from_date) & (data.index <= to_date)]
+        
 
     def _verify_data_alignment(self, data, instrument, feed, period, price_data_path):
         '''
@@ -663,7 +676,7 @@ class AutoTraderBot():
         for order in signal_dict:
             order_signal_dict = signal_dict[order].copy()
             
-            if order_signal_dict["direction"] != 0 or order_signal_dict["order_type"] == 'modify':
+            if (len(order_signal_dict) > 0) and ((order_signal_dict["order_type"] == 'modify') or (order_signal_dict["direction"] != 0)):
                 self._process_signal(order_signal_dict, i, self.data, 
                                     self.quote_data, self.instrument)
         
@@ -679,14 +692,15 @@ class AutoTraderBot():
         if int(self.verbosity) > 1:
             if len(self.latest_orders) > 0:
                 for order in self.latest_orders:
-                    order_string = "{}: {} {}".format(order['order_time'], 
+                    order_string = "{}: {} {}".format(order['order_time'].strftime("%b %d %Y %H:%M:%S"), 
                                                       order['instrument'], 
                                                       order['order_type']) + \
                         " order of {} units placed at {}.".format(order['size'],
                                                                   order['order_price'])
                     print(order_string)
             else:
-                print("{}: No signal detected ({}).".format(datetime.now().strftime("%b %d %H:%M:%S"),
+                if int(self.verbosity) > 2:
+                    print("{}: No signal detected ({}).".format(self.data.index[i].strftime("%b %d %Y %H:%M:%S"),
                                                             self.instrument))
         
         # Check for orders placed and/or scan hits
@@ -840,7 +854,7 @@ class AutoTraderBot():
         order_details                   = order_signal_dict
         order_details["order_time"]     = datetime_stamp
         order_details["strategy"]       = self.strategy.name
-        order_details["instrument"]     = instrument
+        order_details["instrument"]     = order_signal_dict['instrument'] if 'instrument' in order_signal_dict else instrument
         order_details["size"]           = signal*size
         order_details["order_price"]    = order_price
         order_details["HCF"]            = HCF
@@ -891,9 +905,11 @@ class AutoTraderBot():
             
         backtest_dict = {}
         backtest_dict['data']           = self.data
-        backtest_dict['NAV']            = NAV
-        backtest_dict['balance']        = balance
-        backtest_dict['margin']         = margin
+        backtest_dict['account_history'] = pd.DataFrame(data={'balance': balance, 
+                                                              'NAV': NAV, 
+                                                              'margin': margin,
+                                                              'drawdown': np.array(NAV)/np.maximum.accumulate(NAV) - 1}, 
+                                                        index=self.data.index)
         backtest_dict['trade_summary']  = trade_summary
         backtest_dict['indicators']     = self.strategy.indicators if hasattr(self.strategy, 'indicators') else None
         backtest_dict['instrument']     = self.instrument
