@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+'''
+Module: AutoStream
+Purpose: Data stream function for Oanda v20 API.
+Author: Kieran Mackle
+'''
 
-"""
-AutoStream
------------
-Data stream function for Oanda v20 API.
-"""
 
 import v20
 import json
@@ -223,6 +223,7 @@ class AutoStream():
         self.write_to_file  = write_to_file
         self.killfile       = os.path.join(home_dir, 'stopstream')
         self.suspendfile    = os.path.join(home_dir, 'suspendstream')
+        self.stopstream     = False
         
         # Runtime attributes
         self.tick_data      = None
@@ -296,7 +297,7 @@ class AutoStream():
         # Connect to stream and begin processing 
         self.connect_to_stream(self.stream_config)
         
-        while True:
+        while True and not self.stopstream:
             try:
                 self.process_stream(candle_builders,
                                     candle_filenames,
@@ -369,8 +370,6 @@ class AutoStream():
         while os.path.exists(self.suspendfile):
             pass
         
-        # TODO - Reconnect to stream, likely has timed out
-    
     def process_stream(self, candle_builders, candle_filenames, tick_filenames):
         '''
         Processes stream based on run settings.
@@ -387,6 +386,8 @@ class AutoStream():
             # First check for stop file
             if os.path.exists(self.killfile):
                 print("Stop file deteced. Stream stopping.")
+                self.stopstream = True
+                
                 break
             
             # Next check for suspend file
@@ -400,7 +401,7 @@ class AutoStream():
             msg     = json.loads(line)
             tick    = stream_record(msg)
             
-            if self.record_ticks and msg['type'] == 'PRICE':
+            if self.record_ticks and msg['type'] == 'PRICE' and tick.data['instrument'] == self.instruments:
                 # Create tick df from stream record
                 new_tick = {'Bid': tick.data['bid'], 
                             'Ask': tick.data['ask'], 
