@@ -557,11 +557,11 @@ def find_swings(data, data_type='ohlc', n = 2):
         if swings[i] == -1:
             # Down swing - find min price in the vicinity 
             high_list.append(0)
-            low_list.append(min(low_data[i-2:i]))
+            low_list.append(min(low_data[i-n:i]))
             
         elif swings[i] == 1:
             # Up swing - find max price in the vicinity
-            high_list.append(max(high_data[i-2:i]))
+            high_list.append(max(high_data[i-n:i]))
             low_list.append(0)
             
         else:
